package test.apiguardian.api_a;

import org.apiguardian.api.API;
import org.apiguardian.api.API.Status;

@API(status = Status.INTERNAL)
public interface Foo2 {}
